@@ -3,7 +3,7 @@ import sys
 
 def run():
     lessbin = os.path.join(os.path.dirname(__file__),
-                           '..', 'rb', 'bin', 'lessc')
+                           'rb', 'bin', 'lessc')
     os.execv(lessbin, ['lessc'] + sys.argv[1:])
 
 if __name__ == '__main__':
